<?php
/**
 * @package     sumeo
 * @version     1.0
 * @author      NanoAgency
 * @link        http://www.nanoagency.co
 * @copyright   Copyright (c) 2016 NanoAgency
 * @license     GPL v2
 */

/*  Setup Theme ===================================================================================================== */
add_action( 'after_setup_theme', 'sumeo_theme_setup' );
if ( ! function_exists( 'sumeo_theme_setup' ) ) :
    function sumeo_theme_setup() {
        load_theme_textdomain( 'sumeo', get_template_directory() . '/languages' );

        //  Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        //  Let WordPress manage the document title.
        add_theme_support( 'title-tag' );

        //  Enable support for Post Thumbnails on posts and pages.
        add_theme_support( 'post-thumbnails' );

        set_post_thumbnail_size( 825, 510, true );

        add_image_size( 'thumb-image', 600, 450, true);

        //Enable support for Post Formats.
        add_theme_support( 'html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ) );

        add_theme_support( 'post-formats', array(
            'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
        ) );

        add_theme_support( 'custom-header' );

        add_theme_support( 'custom-background' );

        add_theme_support( "title-tag" );

        add_theme_support( 'wp-block-styles' );

        add_theme_support( 'align-wide' );

        add_theme_support( 'editor-styles' );

        add_editor_style( array( 'assets/css/editor-style.css', sumeo_font_url() ) );

        add_theme_support( 'responsive-embeds' );


        add_theme_support( 'editor-color-palette', array(
            array(
                'name' => __( 'strong magenta', 'sumeo' ),
                'slug' => 'strong-magenta',
                'color' => '#a156b4',
            ),
            array(
                'name' => __( 'light grayish magenta', 'sumeo' ),
                'slug' => 'light-grayish-magenta',
                'color' => '#d0a5db',
            ),
            array(
                'name' => __( 'very light gray', 'sumeo' ),
                'slug' => 'very-light-gray',
                'color' => '#eee',
            ),
            array(
                'name' => __( 'very dark gray', 'sumeo' ),
                'slug' => 'very-dark-gray',
                'color' => '#444',
            ),
        ) );

        add_theme_support( 'woocommerce' );

    }
endif;

/* Thumbnail Sizes ================================================================================================== */
set_post_thumbnail_size( 220, 150, true);

add_image_size( 'sumeo-single-post', 1170 ,600, true);

add_image_size( 'sumeo-blog-list', 444 ,474, true);

add_image_size( 'sumeo-blog-tran', 770 ,624, true);

add_image_size( 'sumeo-blog-vertical', 385 ,624, true);

add_image_size( 'sumeo-blog-grid', 380 ,260, true);

add_image_size( 'sumeo-sidebar', 100 ,100, true);

add_image_size( 'sumeo-related-image',370,247,true);

/* Setup Font ======================================================================================================= */
function sumeo_font_url() {
    $fonts_url = '';
    $opensans   = _x( 'on', 'Roboto font: on or off', 'sumeo' );
    $oswald     = _x( 'on', 'Oswald font: on or off', 'sumeo' );

    if ( 'off' !== $opensans || 'off' !== $oswald ) {
        $font_families = array();

        if ( 'off' !== $opensans) {
            $font_families[] = 'Roboto:300,300i,400,400i,500,700,900';
        }
        if ( 'off' !== $oswald ) {
            $font_families[] = 'Oswald';
        }
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );

        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }

    return esc_url_raw( $fonts_url );
}


/* Load Front-end scripts  ========================================================================================== */
add_action( 'wp_enqueue_scripts', 'sumeo_theme_scripts');
function sumeo_theme_scripts() {

    // Add  fonts, used in the main stylesheet.
    wp_enqueue_style( 'sumeo_fonts', sumeo_font_url(), array(), null );

    //style bootstrap
    wp_enqueue_style('bootstrap',get_template_directory_uri().'/assets/css/bootstrap.min.css', array(), '3.0.2 ');

    //style MAIN THEME
    wp_enqueue_style( 'sumeo-main', get_template_directory_uri(). '/style.css', array(), null );

    //style skin
    wp_enqueue_style('sumeo-css', get_template_directory_uri().'/assets/css/style-default.min.css' );

    //register third-party
    wp_enqueue_script( 'plugins', get_template_directory_uri().'/assets/js/plugins.min.js', array(), null, true );
    wp_enqueue_script( 'isotope.pkgd', get_template_directory_uri().'/assets/js/plugins/isotope.pkgd.min.js', array(), '2.2.0', true );
    wp_enqueue_script( 'jquery.sticky-sidebar', get_template_directory_uri().'/assets/js/plugins/jquery.sticky-sidebar.js', array(), '1.4.0',true );
    wp_enqueue_script( 'jquery.sticky', get_template_directory_uri().'/assets/js/plugins/jquery.sticky.js', array(), '1.0.4', true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    if ( is_singular() && wp_attachment_is_image() ) {
        wp_enqueue_script( 'sumeo-theme-keyboard-image-navigation', get_template_directory_uri() . '/assets/js/keyboard-image-navigation.min.js', array( 'jquery' ), '20141010' );
    }

    //jquery MAIN THEME
    wp_enqueue_script('sumeo-isotope-init', get_template_directory_uri() . '/assets/js/dev/isotope-init.js', array('jquery'),null, true);
    wp_enqueue_script('sumeo-js', get_template_directory_uri() . '/assets/js/dev/sumeo.js', array('jquery'),null, true);

}

/* Load Back-end SCRIPTS============================================================================================= */
function sumeo_js_enqueue()
{
    wp_enqueue_media();
    wp_enqueue_style('thickbox');
    wp_enqueue_script('media-upload');
    wp_enqueue_script('thickbox');
    // moved the js to an external file, you may want to change the path
    wp_enqueue_script('information_js',get_template_directory_uri(). '/assets/js/widget.min.js', 'jquery', '1.0', true);
}
add_action('admin_enqueue_scripts', 'sumeo_js_enqueue');

/* Register the required plugins    ================================================================================= */
add_action( 'tgmpa_register', 'sumeo_register_required_plugins' );
function sumeo_register_required_plugins() {

    $plugins = array(
        // This is an example of how to include a plugin pre-packaged with a theme.
        array(
            'name'      => esc_html__( 'Nano Core Plugin', 'sumeo' ),
            'slug'      => 'theme-core',
            'source'    => get_template_directory() . '/inc/plugins/theme-core.zip',
            'required'  => true,
            'version'   => '2.0.0',
            'force_activation' => false,
            'force_deactivation' => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/nano.jpg',

        ),
        //Contact form 7
        array(
            'name'      => esc_html__('Contact Form 7', 'sumeo' ),
            'slug'      => 'contact-form-7',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/contact-form7.jpg',
        ),
        //WPBakery Visual Composer
        array(
            'name'      =>  esc_html__('WPBakery Visual Compose', 'sumeo' ),
            'slug'      => 'js_composer',
            'source'    => get_template_directory() . '/inc/plugins/js_composer.zip',
            'required'  => true,
            'version'   => '5.7',
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/vc.jpg',
        ),
        //MailChimp for WordPress
        array(
            'name'      =>  esc_html__('MailChimp for WordPress ', 'sumeo' ),
            'slug'      => 'mailchimp-for-wp',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/mailchimp.jpg',
        ),
        //Instagram
        array(
            'name'      =>  esc_html__('Instagram Feed', 'sumeo' ),
            'slug'      => 'instagram-feed',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/instagram.jpg',
        ),
        //Classic Editor
        array(
            'name'      =>  esc_html__('Classic Editor', 'sumeo' ),
            'slug'      => 'classic-editor',
            'required'  => false,
        ),
        //Loco Translate
        array(
            'name'      =>  esc_html__('Loco Translate', 'sumeo' ),
            'slug'      => 'loco-translate',
            'required'  => false,
        ),

    );

    $config = array(
        'id'           => 'sumeo',                   // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                       // Default absolute path to pre-packaged plugins.
        'has_notices'  => true,
        'menu'         => 'tgmpa-install-plugins',  // Menu slug.
        'dismiss_msg'  => '',                       // If 'dismissable' is false, this message will be output at top of nag.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'is_automatic' => true,                     // Automatically activate plugins after installation or not.
        'message'      => '',                       // Message to output right before the plugins table.

    );

    tgmpa( $plugins, $config );

}

/* Register Navigation ============================================================================================== */
register_nav_menus( array(
    'primary_navigation'    => esc_html__( 'Primary Navigation', 'sumeo' ),

) );

/* Register Sidebar ================================================================================================= */
if ( function_exists('register_sidebar') ) {
    register_sidebar( array(
        'name'          => esc_html__( 'Archive', 'sumeo' ),
        'id'            => 'archive',
        'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'sumeo' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widgettitle">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Blogs', 'sumeo' ),
        'id'            => 'blogs',
        'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'sumeo' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widgettitle">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Blogs 2', 'sumeo' ),
        'id'            => 'blogs2',
        'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'sumeo' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widgettitle">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar(array(
        'name' => esc_html__('Footer Top','sumeo'),
        'id'   => 'footer-top',
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer 1','sumeo'),
        'id'   => 'footer-1',
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer 2','sumeo'),
        'id'   => 'footer-2',
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer 3','sumeo'),
        'id'   => 'footer-3',
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Custom Header Left','sumeo'),
        'id'   => 'custom-header-middle',
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Copy Right','sumeo'),
        'id'   => 'copy-right',
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));

}